package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.List;

/**
 * UploadSpec
 */
public class ExecuteSpec implements UploadLikeWithLogSpec {
    @Nonnull private final FileSource source;
    @Nullable private final String path;
    @Nullable private final String pwd;
    @Nonnull private final String permissions;
    @Nullable private final Boolean sudo;
    @Nullable private final String log;
    @Nullable private final List<String> nodes;

    public ExecuteSpec(@Nonnull FileSource source,
                       @Nullable String path,
                       @Nullable String pwd,
                       @Nullable String permissions,
                       @Nullable Boolean sudo,
                       @Nullable String log,
                       @Nullable List<String> nodes) {
        this.source = source;
        this.path = path;
        this.pwd = pwd;
        this.permissions = permissions == null ? "u=rwx" : permissions;
        this.sudo = sudo;
        this.log = log;
        this.nodes = nodes;
    }

    @Nonnull
    public FileSource getSource() {
        return source;
    }

    @Nullable
    public String getPath() {
        return path;
    }

    @Nullable
    public String getPwd() {
        return pwd;
    }

    @Nonnull
    public String getPermissions() {
        return permissions;
    }

    /**
     * If null, fall back to global default in config
     * @return
     */
    public Boolean isSudo() {
        return sudo;
    }

    /**
     * @return the path of the log file, or null if it should be determined automatically.
     */
    @Nullable
    @Override
    public String getLog() {
        return log;
    }

    @Nullable
    public List<String> getNodes() {
        return nodes;
    }
}
